// Reading the CSV file from gist
d3.csv(
  'https://gist.githubusercontent.com/ra0912/0dd7bfec8aa877adf952240376b1f59c/raw/863b947b7f47f57c5351d571a8df010740840cfd/rohithice7.csv',
)
  .then(function (data) {
    // Convert string data to numerical values
    data.forEach(function (d) {
      d.Budget = +d.Budget;
      d.Revenue = +d.Revenue;
    });

    drawScatterPlot(data);
  })
  .catch(function (error) {
    // Handle errors while loading data
    console.log('Error loading the data');
    throw error;
  });

function drawScatterPlot(data) {
  const margin = {
    top: 20,
    right: 20,
    bottom: 50,
    left: 50,
  };
  const width = 600 - margin.left - margin.right;
  const height = 400 - margin.top - margin.bottom;

  const svg = d3
    .select('#scatter-plot')
    .append('svg')
    .attr('width', width + margin.left + margin.right)
    .attr('height', height + margin.top + margin.bottom)
    .append('g')
    .attr(
      'transform',
      `translate(${margin.left},${margin.top})`,
    );

  const x = d3
    .scaleLinear()
    .domain([0, d3.max(data, (d) => d.Budget) * 1.1]) // Add a buffer for better visualization
    .range([0, width]);

  const y = d3
    .scaleLinear()
    .domain([0, d3.max(data, (d) => d.Revenue) * 1.1])
    .range([height, 0]);

  svg
    .append('g')
    .attr('transform', `translate(0,${height})`)
    .call(d3.axisBottom(x))
    .append('text')
    .attr('x', width / 2)
    .attr('y', margin.bottom - 5)
    .attr('fill', '#000')
    .style('text-anchor', 'middle')
    .text('Budget');

  svg
    .append('g')
    .call(d3.axisLeft(y))
    .append('text')
    .attr('transform', 'rotate(-90)')
    .attr('y', -margin.left + 10)
    .attr('x', -height / 2)
    .attr('fill', '#000')
    .style('text-anchor', 'middle')
    .text('Revenue');

  svg
    .selectAll('.circle')
    .data(data)
    .enter()
    .append('circle')
    .attr('class', 'circle')
    .attr('cx', (d) => x(d.Budget))
    .attr('cy', (d) => y(d.Revenue))
    .attr('r', 5);
}
